cb424d7448
verify-patch-sanity.py validates every active recipe .patch has internally- consistent hunk line counts — catching the 'malformed patch at line N' failure at commit/CI/preflight time instead of hours into a cook. This cycle hit that class three times (qtwaylandscanner, sddm, xwayland), each only discovered when cookbook tried to apply the patch. Running it across the repo found 29 latent malformed patches (validated against GNU patch: e.g. relibc/P3-sysv-ipc reproduces 'malformed patch at line 22'). They were harmless only because they sit in vendored recipes (baked, not re- applied) — but would fail on any version-bump re-derivation. --fix recounts the hunk headers (body untouched) and repaired all 29. Wired into build-preflight.sh (Phase 1.0D) and redbear-ci.yml, with a unit test (test-patch-sanity.sh). Skips archived/legacy trees and unvalidatable formats (empty placeholders, bare-@@ git hunks).
44 lines
2.1 KiB
Plaintext
44 lines
2.1 KiB
Plaintext
// RUN: %clang_cc1 -fsyntax-only -Wundefined-internal -verify %s
|
|
// RUN: %clang_cc1 -fsyntax-only -Wundefined-internal -fcuda-is-device -verify %s
|
|
|
|
// RUN: %clang_cc1 -fsyntax-only -Wundefined-internal -fgpu-rdc -verify=rdc %s
|
|
// RUN: %clang_cc1 -fsyntax-only -Wundefined-internal -fcuda-is-device -fgpu-rdc -verify=rdc %s
|
|
|
|
// Most of these declarations are fine in separate compilation mode.
|
|
|
|
#include "Inputs/cuda.h"
|
|
|
|
__device__ void foo() {
|
|
extern __shared__ int x; // expected-error {{__shared__ variable 'x' cannot be 'extern'}}
|
|
extern __shared__ int arr[]; // ok
|
|
extern __shared__ int arr0[0]; // expected-error {{__shared__ variable 'arr0' cannot be 'extern'}}
|
|
extern __shared__ int arr1[1]; // expected-error {{__shared__ variable 'arr1' cannot be 'extern'}}
|
|
extern __shared__ int* ptr ; // expected-error {{__shared__ variable 'ptr' cannot be 'extern'}}
|
|
}
|
|
|
|
__host__ __device__ void bar() {
|
|
extern __shared__ int arr[]; // ok
|
|
extern __shared__ int arr0[0]; // expected-error {{__shared__ variable 'arr0' cannot be 'extern'}}
|
|
extern __shared__ int arr1[1]; // expected-error {{__shared__ variable 'arr1' cannot be 'extern'}}
|
|
extern __shared__ int* ptr ; // expected-error {{__shared__ variable 'ptr' cannot be 'extern'}}
|
|
}
|
|
|
|
extern __shared__ int global; // expected-error {{__shared__ variable 'global' cannot be 'extern'}}
|
|
extern __shared__ int global_arr[]; // ok
|
|
extern __shared__ int global_arr1[1]; // expected-error {{__shared__ variable 'global_arr1' cannot be 'extern'}}
|
|
|
|
// Check that, iff we're not in rdc mode, extern __shared__ can appear in an
|
|
// anonymous namespace / in a static function without generating a warning
|
|
// about a variable with internal linkage but no definition
|
|
// (-Wundefined-internal).
|
|
namespace {
|
|
extern __shared__ int global_arr[]; // rdc-warning {{has internal linkage but is not defined}}
|
|
__global__ void in_anon_ns() {
|
|
extern __shared__ int local_arr[]; // rdc-warning {{has internal linkage but is not defined}}
|
|
|
|
// Touch arrays to generate the warning.
|
|
local_arr[0] = 0; // rdc-note {{used here}}
|
|
global_arr[0] = 0; // rdc-note {{used here}}
|
|
}
|
|
} // namespace
|